@@ -25,7 +25,7 @@ pub fn is_current_round_valid(aggregator: &AggregatorState) -> Result<bool, Prog
 ///
 /// Returns a ProgramError if the AccountInfo is unable to be borrowed or the
 /// account is not initialized as an aggregator.
-pub fn get_aggregator<'a>(switchboard_feed: &'a AccountInfo<'a>) -> Result<AggregatorState, ProgramError> {
+pub fn get_aggregator(switchboard_feed: &AccountInfo) -> Result<AggregatorState, ProgramError> {
     let state_buffer = switchboard_feed.try_borrow_data()?;
     let aggregator_state: AggregatorState =
         deserialize_from_slice(&state_buffer[1..]).map_err(|_| ProgramError::InvalidAccountData)?;
@@ -33,7 +33,7 @@ pub fn get_aggregator<'a>(switchboard_feed: &'a AccountInfo<'a>) -> Result<Aggre
 }
 
 /// Returns the most recent resolution round that is considered valid for the aggregator.
-pub fn get_aggregator_result<'a>(aggregator: &AggregatorState) -> Result<RoundResult, ProgramError> {
+pub fn get_aggregator_result(aggregator: &AggregatorState) -> Result<RoundResult, ProgramError> {
     let mut maybe_round = aggregator.current_round_result.clone();
     if !is_current_round_valid(&aggregator)? {
         maybe_round = aggregator.last_round_result.clone();
